@@ -119,7 +119,8 @@ HotstartStack = R6Class("HotstartStack",
 
     #' @description
     #' Helper for print outputs.
-    format = function() {
+    #' @param ... (ignored).
+    format = function(...) {
       sprintf("<%s>", class(self)[1L])
     },
 
