@@ -38,7 +38,7 @@ MeasureSelectedFeatures = R6Class("MeasureSelectedFeatures",
         param_set = param_set,
         task_type = NA_character_,
         properties = c("requires_task", "requires_learner", "requires_model"),
-        predict_type = "response",
+        predict_type = NA_character_,
         range = c(0, Inf),
         minimize = TRUE,
         label = "Absolute or Relative Frequency of Selected Features",
