@@ -91,4 +91,4 @@ ResamplingCV = R6Class("ResamplingCV", inherit = Resampling,
 )
 
 #' @include mlr_resamplings.R
-mlr_resamplings$add("cv", ResamplingCV)
+mlr_resamplings$add("cv", function() ResamplingCV$new())
